searchData={"items":[{"type":"module","title":"MDEx","doc":"A fast 100% CommonMark-compatible GitHub Flavored Markdown parser and formatter for Elixir.","ref":"MDEx.html"},{"type":"module","title":"Features - MDEx","doc":"- Fast. Check out the [benchmark](https://github.com/leandrocp/mdex#benchmark)\n- Compatible with [CommonMark spec](https://spec.commonmark.org) and [GitHub Flavored Markdown Spec](https://github.github.com/gfm/)\n- Binary is precompiled, no need to compile anything\n- Code syntax highlithging, performed by [autumn](https://github.com/leandrocp/autumn)\n\nCheck out some samples at https://mdex-c31.pages.dev","ref":"MDEx.html#module-features"},{"type":"module","title":"Installation - MDEx","doc":"Add `:mdex` dependecy:\n\n```elixir\ndef deps do\n  [\n    {:mdex, \"~> 0.1\"}\n  ]\nend\n```","ref":"MDEx.html#module-installation"},{"type":"module","title":"Usage - MDEx","doc":"```elixir\nMix.install([{:mdex, \"~> 0.1\"}])\n```\n\n```elixir\nMDEx.to_html(\"# Hello\")\n#=> \" Hello \\n\"\n```\n\n```elixir\nMDEx.to_html(~S\"\"\"\n# MDEx\n\nSome benefits you'll find:\n- Fast\n- CommonMark spec\n- Binary is precompiled, no need to compile anything\n\"\"\") |> IO.puts()\n#=>\n#=>  MDEx \n#=>  Some benefits you'll find: \n#=>  \n#=>  Fast \n#=>  CommonMark spec \n#=>  Binary is precompiled, no need to compile anything \n#=>  Easier to work with since it's Rust \n#=>  \n```\n\n```elixir\nMDEx.to_html(~S\"\"\"\n# And more...\n\n* Code syntax highlight is also available:\n\n\\`\\`\\`elixir\nString.upcase(\"elixir\")\n\\`\\`\\`\n\"\"\") |> IO.puts()\n#=>  And more... \n#=>  \n#=>  Code syntax highlight is also available: \n#=>  \n#=>  \n#=>  \n#=>  String  .  upcase  (  &quot;elixir&quot;  ) \n#=>   \n```","ref":"MDEx.html#module-usage"},{"type":"module","title":"Demo and Samples - MDEx","doc":"A [livebook](https://github.com/leandrocp/mdex/blob/main/playground.livemd) and a [script](https://github.com/leandrocp/mdex/blob/main/playground.exs) are available to demo and experiment,\nor you can check out all [available samples](https://github.com/leandrocp/mdex/tree/main/priv/generated/samples) at https://mdex-c31.pages.dev","ref":"MDEx.html#module-demo-and-samples"},{"type":"module","title":"Benchmark - MDEx","doc":"A [simple script](benchmark.exs) is available to compare existing libs:\n\n```\nName              ips        average  deviation         median         99th %\ncmark         24.01 K      0.0417 ms    ±14.11%      0.0405 ms      0.0631 ms\nmdex          16.37 K      0.0611 ms     ±9.65%      0.0601 ms      0.0870 ms\nmd             0.85 K        1.18 ms     ±4.72%        1.16 ms        1.36 ms\nearmark        0.47 K        2.14 ms     ±2.82%        2.13 ms        2.42 ms\n\nComparison:\ncmark         24.01 K\nmdex          16.37 K - 1.47x slower +0.0194 ms\nmd             0.85 K - 28.36x slower +1.14 ms\nearmark        0.47 K - 51.47x slower +2.10 ms\n```","ref":"MDEx.html#module-benchmark"},{"type":"module","title":"Motivation - MDEx","doc":"If any of the available libraries are working for you, keep using it, if not then keep reading.\n\n* `earmark` [can't parse](https://github.com/RobertDober/earmark_parser/issues/126) all kinds of documents and is slow to convert hundreds of markdowns.\n* `md` is fast enough and extensible but the doc says \"If one needs to perfectly parse the common markdown, Md is probably not the correct choice\" so it also fails to parse many documents.\n* `markdown` is not precompiled and has not received updates in a while.\n* `cmark` is a fast CommonMark parser but it requires compiling the C library.","ref":"MDEx.html#module-motivation"},{"type":"module","title":"Looking for help with your Elixir project? - MDEx","doc":"At DockYard we are [ready to help you build your next Elixir project](https://dockyard.com/phoenix-consulting).\nWe have a unique expertise in Elixir and Phoenix development that is unmatched and we love to [write about Elixir](https://dockyard.com/blog/categories/elixir).\n\nHave a project in mind? [Get in touch](https://dockyard.com/contact/hire-us)!","ref":"MDEx.html#module-looking-for-help-with-your-elixir-project"},{"type":"module","title":"Acknowledgements - MDEx","doc":"* Use Rust's [comrak crate](https://crates.io/crates/comrak) under the hood.\n* [Logo](https://www.flaticon.com/free-icons/rpg) created by by Freepik - Flaticon\n* [Logo font](https://github.com/quoteunquoteapps/CourierPrime) designed by [Alan Greene](https://github.com/a-dg)","ref":"MDEx.html#module-acknowledgements"},{"type":"function","title":"MDEx.to_html/1","doc":"Convert `markdown` to HTML.","ref":"MDEx.html#to_html/1"},{"type":"function","title":"Examples - MDEx.to_html/1","doc":"iex> MDEx.to_html(\"# MDEx\")\n    \" MDEx \\n\"\n\n    iex> MDEx.to_html(\"Implemented with:\\n1. Elixir\\n2. Rust\")\n    \" Implemented with: \\n \\n Elixir \\n Rust \\n \\n\"","ref":"MDEx.html#to_html/1-examples"},{"type":"function","title":"MDEx.to_html/2","doc":"Convert `markdown` to HTML with custom `opts`.","ref":"MDEx.html#to_html/2"},{"type":"function","title":"Options - MDEx.to_html/2","doc":"Accepts all available [Comrak Options](https://docs.rs/comrak/latest/comrak/struct.ComrakOptions.html) as keyword lists.\n\n* `:extension` - https://docs.rs/comrak/latest/comrak/struct.ComrakExtensionOptions.html\n* `:parse` - https://docs.rs/comrak/latest/comrak/struct.ComrakParseOptions.html\n* `:render` - https://docs.rs/comrak/latest/comrak/struct.ComrakRenderOptions.html\n* `:features` - see the available options below\n\n#","ref":"MDEx.html#to_html/2-options"},{"type":"function","title":"Features Options - MDEx.to_html/2","doc":"* `:sanitize` (default `false`) - sanitize output using [ammonia](https://crates.io/crates/ammonia).\n Recommended if passing `render: [unsafe_: true]`\n* `:syntax_highlight_theme` (default `\"onedark\"`) - syntax highlight code fences using [autumn themes](https://github.com/leandrocp/autumn/tree/main/priv/themes),\nyou should pass the filename without special chars and without extension, for example you should pass `syntax_highlight_theme: \"adwaita_dark\"` to use the [Adwaita Dark](https://github.com/leandrocp/autumn/blob/main/priv/themes/adwaita-dark.toml) theme.","ref":"MDEx.html#to_html/2-features-options"},{"type":"function","title":"Examples - MDEx.to_html/2","doc":"iex> MDEx.to_html(\"# MDEx\")\n    \" MDEx \\n\"\n\n    iex> MDEx.to_html(\"Implemented with:\\n1. Elixir\\n2. Rust\")\n    \" Implemented with: \\n \\n Elixir \\n Rust \\n \\n\"\n\n    iex> MDEx.to_html(\"Hello ~world~ there\", extension: [strikethrough: true])\n    \" Hello  world  there \\n\"\n\n    iex> MDEx.to_html(\" visit https://https://beaconcms.org \", extension: [autolink: true], render: [unsafe_: true])\n    \"  visit  https://https://beaconcms.org   \\n\"\n\n    iex> MDEx.to_html(\"# Title with  console.log('dangerous script') \", render: [unsafe_: true], features: [sanitize: true])\n    \" Title with  \\n\"","ref":"MDEx.html#to_html/2-examples"},{"type":"task","title":"mix mdex.generate_samples","doc":"","ref":"Mix.Tasks.Mdex.GenerateSamples.html"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"0.1.11 - Changelog","doc":"#","ref":"changelog.html#0-1-11"},{"type":"extras","title":"Fixes - Changelog","doc":"* Syntax highlighting - remove newlines to avoid formatting incorrectly","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.10 (2023-10-24) - Changelog","doc":"#","ref":"changelog.html#0-1-10-2023-10-24"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add translate=\"no\" attr in   tag\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* Fix Javascript syntax highlight\n  * Fix Typescript syntax highlight","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.9 (2023-09-29) - Changelog","doc":"#","ref":"changelog.html#0-1-9-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add logo\n  * Add icon","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.8 (2023-09-29) - Changelog","doc":"#","ref":"changelog.html#0-1-8-2023-09-29"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fallback to plain text on invalid language\n  * Syntax highlight injections\n  * Add samples","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.7 (2023-09-27) - Changelog","doc":"#","ref":"changelog.html#0-1-7-2023-09-27"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Syntax highlight code using tree-sitter and helix editor themes. Use https://github.com/leandrocp/autumn/tree/main/native/inkjet_nif under the hood.","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.6 (2023-09-14) - Changelog","doc":"#","ref":"changelog.html#0-1-6-2023-09-14"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Load extra themes and syntaxes with https://crates.io/crates/two-face","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.5 (2023-09-12) - Changelog","doc":"#","ref":"changelog.html#0-1-5-2023-09-12"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Sanitize output with https://crates.io/crates/ammonia\n  * Syntax Highlight with https://crates.io/crates/syntect","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.4 (2023-09-11) - Changelog","doc":"#","ref":"changelog.html#0-1-4-2023-09-11"},{"type":"extras","title":"Fixes - Changelog","doc":"* Compile on Ubuntu 20 to fix libc version mismatch","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.3 (2023-09-11) - Changelog","doc":"#","ref":"changelog.html#0-1-3-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* NIF version 2.15","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.2 (2023-09-11) - Changelog","doc":"#","ref":"changelog.html#0-1-2-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Guard markdown arg\n\n#","ref":"changelog.html#enhancements"},{"type":"extras","title":"Fixes - Changelog","doc":"* specs","ref":"changelog.html#fixes"},{"type":"extras","title":"0.1.1 (2023-09-11) - Changelog","doc":"#","ref":"changelog.html#0-1-1-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update Rust to edition 2021\n  * Add `@spec` to public functions","ref":"changelog.html#enhancements"},{"type":"extras","title":"0.1.0 (2023-09-11) - Changelog","doc":"#","ref":"changelog.html#0-1-0-2023-09-11"},{"type":"extras","title":"Enhancements - Changelog","doc":"* `MDEx.to_html/1` to convert Markdown to HTML using default options.\n  * `MDEx.to_html/2` to convert Markdown to HTML using custom options.","ref":"changelog.html#enhancements"}],"content_type":"text/markdown"}